@@ -139,7 +139,7 @@ class dyn_obj:
 
         int_curveOB.data.bevel_factor_start = 0
 
-        bpy.ops.object.convert(target='MESH')
+        curve_to_mesh(int_curveOB)
 
         if staticity == 'dynamic':
             bpy.ops.object.modifier_add(type='BUILD')
@@ -239,3 +239,23 @@ class anim_text:
 
             bpy.app.handlers.frame_change_pre.append(recalculate_text)
 
+def curve_to_mesh(curve):
+    context = bpy.context
+    deg = context.evaluated_depsgraph_get()
+    me = bpy.data.meshes.new_from_object(curve.evaluated_get(deg), depsgraph=deg)
+    
+    curve_name = curve.name
+
+    new_obj = bpy.data.objects.new(curve.name + "_mesh", me)
+    context.collection.objects.link(new_obj)
+
+    for o in context.selected_objects:
+        o.select_set(False)
+
+    new_obj.matrix_world = curve.matrix_world
+    new_obj.select_set(True)
+    context.view_layer.objects.active = new_obj
+    
+    bpy.data.objects.remove(curve, do_unlink=True)
+    new_obj.name = curve_name
+
